==> zio-aws-elasticloadbalancingv2_2.12-5.17.129.1-sources.jar: zio/aws/elasticloadbalancingv2/model/SubnetMapping.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.elasticloadbalancingv2.model.primitives.{
  IPv6Address,
  PrivateIPv4Address,
  AllocationId,
  SubnetId
}
import scala.jdk.CollectionConverters._
final case class SubnetMapping(
    subnetId: Option[SubnetId] = None,
    allocationId: Option[AllocationId] = None,
    privateIPv4Address: Option[PrivateIPv4Address] = None,
    iPv6Address: Option[IPv6Address] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping = {
    import SubnetMapping.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
      .builder()
      .optionallyWith(
        subnetId.map(value => SubnetId.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        allocationId.map(value => AllocationId.unwrap(value): java.lang.String)
      )(_.allocationId)
      .optionallyWith(
        privateIPv4Address.map(value =>
          PrivateIPv4Address.unwrap(value): java.lang.String
        )
      )(_.privateIPv4Address)
      .optionallyWith(
        iPv6Address.map(value => IPv6Address.unwrap(value): java.lang.String)
      )(_.iPv6Address)
      .build()
  }
  def asReadOnly: zio.aws.elasticloadbalancingv2.model.SubnetMapping.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.SubnetMapping.wrap(buildAwsValue())
}
object SubnetMapping {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticloadbalancingv2.model.SubnetMapping =
      zio.aws.elasticloadbalancingv2.model.SubnetMapping(
        subnetId.map(value => value),
        allocationId.map(value => value),
        privateIPv4Address.map(value => value),
        iPv6Address.map(value => value)
      )
    def subnetId: Option[SubnetId]
    def allocationId: Option[AllocationId]
    def privateIPv4Address: Option[PrivateIPv4Address]
    def iPv6Address: Option[IPv6Address]
    def getSubnetId: ZIO[Any, AwsError, SubnetId] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getAllocationId: ZIO[Any, AwsError, AllocationId] =
      AwsError.unwrapOptionField("allocationId", allocationId)
    def getPrivateIPv4Address: ZIO[Any, AwsError, PrivateIPv4Address] =
      AwsError.unwrapOptionField("privateIPv4Address", privateIPv4Address)
    def getIPv6Address: ZIO[Any, AwsError, IPv6Address] =
      AwsError.unwrapOptionField("iPv6Address", iPv6Address)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
  ) extends zio.aws.elasticloadbalancingv2.model.SubnetMapping.ReadOnly {
    override val subnetId: Option[SubnetId] = scala
      .Option(impl.subnetId())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.SubnetId(value)
      )
    override val allocationId: Option[AllocationId] = scala
      .Option(impl.allocationId())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.AllocationId(value)
      )
    override val privateIPv4Address: Option[PrivateIPv4Address] = scala
      .Option(impl.privateIPv4Address())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives
          .PrivateIPv4Address(value)
      )
    override val iPv6Address: Option[IPv6Address] = scala
      .Option(impl.iPv6Address())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.IPv6Address(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
  ): zio.aws.elasticloadbalancingv2.model.SubnetMapping.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-elasticloadbalancingv2_2.12-5.20.37.1-sources.jar: zio/aws/elasticloadbalancingv2/model/SubnetMapping.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.elasticloadbalancingv2.model.primitives.{
  IPv6Address,
  PrivateIPv4Address,
  AllocationId,
  SubnetId
}
import scala.jdk.CollectionConverters._
final case class SubnetMapping(
    subnetId: Optional[SubnetId] = Optional.Absent,
    allocationId: Optional[AllocationId] = Optional.Absent,
    privateIPv4Address: Optional[PrivateIPv4Address] = Optional.Absent,
    iPv6Address: Optional[IPv6Address] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping = {
    import SubnetMapping.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
      .builder()
      .optionallyWith(
        subnetId.map(value => SubnetId.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        allocationId.map(value => AllocationId.unwrap(value): java.lang.String)
      )(_.allocationId)
      .optionallyWith(
        privateIPv4Address.map(value =>
          PrivateIPv4Address.unwrap(value): java.lang.String
        )
      )(_.privateIPv4Address)
      .optionallyWith(
        iPv6Address.map(value => IPv6Address.unwrap(value): java.lang.String)
      )(_.iPv6Address)
      .build()
  }
  def asReadOnly: zio.aws.elasticloadbalancingv2.model.SubnetMapping.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.SubnetMapping.wrap(buildAwsValue())
}
object SubnetMapping {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticloadbalancingv2.model.SubnetMapping =
      zio.aws.elasticloadbalancingv2.model.SubnetMapping(
        subnetId.map(value => value),
        allocationId.map(value => value),
        privateIPv4Address.map(value => value),
        iPv6Address.map(value => value)
      )
    def subnetId: Optional[SubnetId]
    def allocationId: Optional[AllocationId]
    def privateIPv4Address: Optional[PrivateIPv4Address]
    def iPv6Address: Optional[IPv6Address]
    def getSubnetId: ZIO[Any, AwsError, SubnetId] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getAllocationId: ZIO[Any, AwsError, AllocationId] =
      AwsError.unwrapOptionField("allocationId", allocationId)
    def getPrivateIPv4Address: ZIO[Any, AwsError, PrivateIPv4Address] =
      AwsError.unwrapOptionField("privateIPv4Address", privateIPv4Address)
    def getIPv6Address: ZIO[Any, AwsError, IPv6Address] =
      AwsError.unwrapOptionField("iPv6Address", iPv6Address)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
  ) extends zio.aws.elasticloadbalancingv2.model.SubnetMapping.ReadOnly {
    override val subnetId: Optional[SubnetId] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.SubnetId(value)
      )
    override val allocationId: Optional[AllocationId] = zio.aws.core.internal
      .optionalFromNullable(impl.allocationId())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.AllocationId(value)
      )
    override val privateIPv4Address: Optional[PrivateIPv4Address] =
      zio.aws.core.internal
        .optionalFromNullable(impl.privateIPv4Address())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives
            .PrivateIPv4Address(value)
        )
    override val iPv6Address: Optional[IPv6Address] = zio.aws.core.internal
      .optionalFromNullable(impl.iPv6Address())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.IPv6Address(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.SubnetMapping
  ): zio.aws.elasticloadbalancingv2.model.SubnetMapping.ReadOnly = new Wrapper(
    impl
  )
}
